\name{ACC}
\alias{ACC}
\title{
  Compute Anomaly Correlation Coefficient
}
\description{
  Matrix var_exp & var_obs should have dimensions (nexp/nobs, nsdates, nltimes, 
  nlat, nlon).
  ACC computes the Anomaly Correlation Coefficient for each jexp in 1:nexp and 
  each jobs in 1:nobs which gives nexp x nobs ACC for each startdate and each 
  leadtime.
  The confidence interval is computed by a Fisher transformation.
  The significance level relies on a one-sided student-T distribution.
  A domain can be selected by providing the list of longitudes/latitudes 
  (lon/lat) of the grid together with the corner of the domain:
    lonlatbox = c(lonmin, lonmax, latmin, latmax)
}
\usage{
  ACC(var_exp, var_obs, lon = NULL, lat = NULL, lonlatbox = NULL)
}
\arguments{
  \item{var_exp}{
    Matrix of experimental data.
  }
  \item{var_obs}{
    Matrix of observational data, same dimensions as var_exp except along the 
    first dimension.
  }
  \item{lon}{
    Array of longitudes of the var_exp/var_obs grids, optional.
  }
  \item{lat}{
    Array of latitudes of the var_exp/var_obs grids, optional.
  }
  \item{lonlatbox}{
    Domain to select c(lonmin, lonmax, latmin, latmax), optional.
  }
}
\value{
  \item{ACC}{
    Matrix with c(nexp, nobs, nsdates, nleadtimes, 4) dimensions.
    The fourth dimension of length 4 corresponds to the lower limit of the 95% 
    confidence interval, the computed ACC, the upper limit of the 95% 
    confidence interval and the 95% significance level given by a one-sided 
    T-test.
  }
  \item{MACC}{
    Mean Anomaly Correlation Coefficient with c(nexp, nobs, nleadtimes) 
    dimensions.
  }
}
\author{
  History:
  1.0  -  2013-08  (V. Guemas, \email{vguemas@ic3.cat})  -  Original code
}
\keyword{datagen}
