\name{PlotVsLTime}
\alias{PlotVsLTime}
\title{
  Plot Data Along Forecast Time
}
\description{
  Plots mean InterQuartile Range, Maximum-Mininum, Standard Deviation, Median 
  Absolute Deviation, the trends, the RMS and correlation between modelled and 
  observed data against the forecast time for all input experiments.
}
\usage{
  PlotVsLTime(var, toptitle = "", ytitle = "", monini = 1, freq = 12, 
  nticks = NULL, limits = NULL, listexp = c("exp1", "exp2", "exp3"), 
  listobs = c("obs1", "obs2", "obs3"), biglab = F, hlines = NULL, leg = T, 
  siglev = F, fileout = "output_plotvsltime.eps", sizetit = 1, show_conf = T)
}
\arguments{
  \item{var}{
    Matrix of dimensions:
         (nexp/nmod, 3 ,nltime)
      or (nexp/nmod, nobs, 3 ,nltime)
  }
  \item{toptitle}{
    Main title, optional.
  }
  \item{ytitle}{
    Title of Y-axis, optional.
  }
  \item{monini}{
    Starting month between 1 and 12. Default = 1.
  }
  \item{freq}{
    1 = yearly, 12 = monthly, 4 = seasonal, ... Default = 12.
  }
  \item{nticks}{
    Number of ticks and labels on the x-axis, optional.
  }
  \item{limits}{
    c(lower limit, upper limit): limits of the Y-axis, optional.
  }
  \item{listexp}{
    List of experiment names, optional.
  }
  \item{listobs}{
    List of observation names, optional.
  }
  \item{biglab}{
    T/F for presentation/paper plot. Default = F.
  }
  \item{hlines}{
    c(a,b, ..) Add horizontal black lines at Y-positions a,b, ...
    Default = NULL.
  }
  \item{leg}{
    T/F if legend should be added or not to the plot. Default = T.
  }
  \item{siglev}{
    T/F if significance level should replace confidence interval.
    Default = F.
  }
  \item{fileout}{
    Name of output ps file.
  }
  \item{sizetit}{
    Multiplicative factor to change title size, optional.
  }
  \item{show_conf}{
    T/F to show/not confidence intervals for input variables.
  }
}
\details{
  Examples of input:
  ------------------

  1- Model output from load/ano/smoothing:
       (nmod, nmemb, sdate, nltime)
     then passed through spread(var, posdim = 2, narm = T) and 
     mean1dim(var, posdim = 3, narm=T) or through 
     trend(mean1dim(var, 2), posTR = 2):
       (nmod, 3, nltime)
     plots average along start dates of IQR/MaxMin/SD/MAD across members or 
     trends of the ensemble-mean computed accross the start dates
     
  2- Model and observed output from load/ano/smoothing:
       (nmod, nmemb, sdate, nltime) and (nobs, nmemb, sdate, nltime)
     then averaged along members mean1dim(var_exp/var_obs, posdim = 2):
       (nmod, sdate, nltime) and (nobs, sdate, nltime)
     then passed through corr(exp, obs, posloop = 1, poscor = 2) or 
     RMS(exp, obs, posloop = 1, posRMS = 2):
       (nmod, nobs, 3, nltime)
     plots correlations or RMS between each exp & each obs against lead-time.
}
\author{
  History:
  1.0  -  2011-03  (V. Guemas, \email{vguemas@ic3.cat})  -  Original code
       -  2013-03  (I. Andreu-Burillo,                   -  Introduced parameter
       -         \email{isabel.andreu-burillo@ic3.cat})  -  sizetit
       -  2013-10  (I. Andreu-Burillo,                   -  Introduced parameter
       -         \email{isabel.andreu-burillo@ic3.cat})  -  show_conf 
}
\keyword{dynamic}
